==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1LeaseSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public interface V1beta1LeaseSpecFluent<A extends V1beta1LeaseSpecFluent<A>> extends Fluent<A>{


    public DateTime getAcquireTime();
    public A withAcquireTime(DateTime acquireTime);
    public Boolean hasAcquireTime();
    public A withNewAcquireTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewAcquireTime(long arg0);
    public A withNewAcquireTime(Object arg0);
    public String getHolderIdentity();
    public A withHolderIdentity(String holderIdentity);
    public Boolean hasHolderIdentity();
    public Integer getLeaseDurationSeconds();
    public A withLeaseDurationSeconds(Integer leaseDurationSeconds);
    public Boolean hasLeaseDurationSeconds();
    public A withNewLeaseDurationSeconds(int arg1);
    public A withNewLeaseDurationSeconds(String arg1);
    public Integer getLeaseTransitions();
    public A withLeaseTransitions(Integer leaseTransitions);
    public Boolean hasLeaseTransitions();
    public A withNewLeaseTransitions(int arg1);
    public A withNewLeaseTransitions(String arg1);
    public DateTime getRenewTime();
    public A withRenewTime(DateTime renewTime);
    public Boolean hasRenewTime();
    public A withNewRenewTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewRenewTime(long arg0);
    public A withNewRenewTime(Object arg0);



}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1LeaseSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public interface V1beta1LeaseSpecFluent<A extends V1beta1LeaseSpecFluent<A>> extends Fluent<A>{


    public DateTime getAcquireTime();
    public A withAcquireTime(DateTime acquireTime);
    public Boolean hasAcquireTime();
    public A withNewAcquireTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewAcquireTime(Object arg0);
    public A withNewAcquireTime(long arg0);
    public String getHolderIdentity();
    public A withHolderIdentity(String holderIdentity);
    public Boolean hasHolderIdentity();
    public A withNewHolderIdentity(String arg1);
    public A withNewHolderIdentity(StringBuilder arg1);
    public A withNewHolderIdentity(StringBuffer arg1);
    public Integer getLeaseDurationSeconds();
    public A withLeaseDurationSeconds(Integer leaseDurationSeconds);
    public Boolean hasLeaseDurationSeconds();
    public Integer getLeaseTransitions();
    public A withLeaseTransitions(Integer leaseTransitions);
    public Boolean hasLeaseTransitions();
    public DateTime getRenewTime();
    public A withRenewTime(DateTime renewTime);
    public Boolean hasRenewTime();
    public A withNewRenewTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewRenewTime(Object arg0);
    public A withNewRenewTime(long arg0);



}
